git

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clone

func Clone(url, destPath string) error

Clone clones a repository to the specified path with progress output

func GetCurrentBranch

func GetCurrentBranch(repoPath string) (string, error)

GetCurrentBranch returns the current branch name for a repository

func GetRemoteURL

func GetRemoteURL(repoPath string) (string, error)

GetRemoteURL returns the remote URL for a repository

func IsGitRepo

func IsGitRepo(path string) bool

IsGitRepo checks if a directory is a git repository

Types

This section is empty.

Jump to